@@ -1,18 +1,19 @@
 import boto3
 import argparse
 import logging
+import emoji
 from colorama import Fore
 from datetime import datetime
 from .aws.describe_organization import describe_organization, \
     list_accounts, index_accounts, list_roots, list_organizational_units, index_ous
 from .aws.describe_identity_store import order_accounts_assignments_list, extend_account_assignments, \
-    list_groups, get_members, list_users, complete_group_members, add_users_and_groups_assign
+    list_groups, get_members, list_users, complete_group_members, add_users_and_groups_assign, l_groups_to_d_groups
 from .aws.describe_sso import list_instances, extends_permissions_set, list_permissions_set
 from .dgms.graph_mapper import create_mapper, create_sso_mapper_complete, create_sso_mapper, create_file
 from .dgms.graph_template import graph_template, graph_template_sso, graph_template_sso_complete
 from .banner.banner import get_version
 
-__version__ = "0.1.8"
+__version__ = "0.2.2"
 
 
 def main() -> int:
@@ -60,29 +61,31 @@ def main() -> int:
 
             client_org = boto3.client('organizations')
             organization = describe_organization(client_org)
-            print(Fore.BLUE + "🔄 Getting Organization Info" + Fore.RESET)
+            print(Fore.BLUE + emoji.emojize(":sparkle: Getting Organization Info" + Fore.RESET))
             logging.debug(organization)
             logging.debug("The Roots Info")
             roots = list_roots(client=client_org)
             logging.debug(roots)
-            print(Fore.BLUE + "🔄 The Organizational Units list " + Fore.RESET)
+            print(Fore.BLUE + emoji.emojize(":sparkle: The Organizational Units list " + Fore.RESET))
             logging.debug("The Organizational Units list ")
             ous = list_organizational_units(parent_id=roots[0]["Id"], client=client_org)
             logging.debug(ous)
             logging.debug("The Organizational Units list with parents info")
             i_ous = index_ous(ous, client=client_org)
             logging.debug(i_ous)
-            print(Fore.BLUE + "🔄 Getting the Account list info" + Fore.RESET)
+            print(Fore.BLUE + emoji.emojize(":sparkle: Getting the Account list info" + Fore.RESET))
             l_accounts = list_accounts(client_org)
             logging.debug(l_accounts)
             logging.debug("The Account list with parents info")
+            print(Fore.YELLOW + emoji.emojize(
+                f":information:  There are {len(l_accounts)} in your organization" + Fore.RESET))
             i_accounts = index_accounts(l_accounts)
             logging.debug(i_accounts)
 
             create_mapper(template_file="graph_org.py", org=organization, root_id=roots[0]["Id"], list_ous=ous,
                           list_accounts=i_accounts)
 
-            print(Fore.YELLOW + "Run -> python3 graph_org.py " + Fore.RESET)
+            print(Fore.YELLOW + emoji.emojize(":sparkles:   Run -> python3 graph_org.py " + Fore.RESET))
 
         if args.graph_identity:
             create_file(template_content=graph_template_sso, file_name="graph_sso.py")
@@ -92,15 +95,15 @@ def main() -> int:
             client_sso = boto3.client('sso-admin', region_name=region)
 
             store_instances = list_instances(client=client_sso)
-            print(Fore.BLUE + "🔄 Getting Identity store instance info" + Fore.RESET)
+            print(Fore.BLUE + emoji.emojize(":sparkle: Getting Identity store instance info" + Fore.RESET))
             logging.debug(store_instances)
             store_id = store_instances[0]["IdentityStoreId"]
             store_arn = store_instances[0]["InstanceArn"]
-            print(Fore.BLUE + "List groups" + Fore.RESET)
+            print(Fore.BLUE + emoji.emojize(":sparkle: List groups" + Fore.RESET))
             l_groups = list_groups(store_id, client=client_identity)
             logging.debug(l_groups)
 
-            print(Fore.BLUE + "🔄Get groups and Users info" + Fore.RESET)
+            print(Fore.BLUE + emoji.emojize(":sparkle: Get groups and Users info" + Fore.RESET))
 
             m_groups = get_members(store_id, l_groups, client=client_identity)
 
@@ -110,6 +113,7 @@ def main() -> int:
             l_users = list_users(store_id, client=client_identity)
             logging.debug(l_users)
             c_users_and_groups = complete_group_members(m_groups, l_users)
+            d_groups = l_groups_to_d_groups(l_groups=c_users_and_groups)
 
             logging.debug(c_users_and_groups)
             # Get Account assingments
@@ -128,14 +132,17 @@ def main() -> int:
                                                               user_and_group_list=c_users_and_groups,
                                                               user_list=l_users,
                                                               list_permissions_set_arn_name=l_permissions_set_arn_name)
-            print(Fore.BLUE + "🔄 Getting account assignments, users and groups" + Fore.RESET)
+            print(Fore.BLUE + emoji.emojize(":sparkle: Getting account assignments, users and groups" + Fore.RESET))
             f_accounts = order_accounts_assignments_list(accounts_dict=l_accounts,
                                                          account_assignments=account_assignments)
-            create_sso_mapper_complete(template_file="graph_sso_complete.py", acc_assignments=f_accounts)
+
+            create_sso_mapper_complete(template_file="graph_sso_complete.py",
+                                       acc_assignments=f_accounts,
+                                       d_groups=d_groups)
             create_sso_mapper(template_file="graph_sso.py", group_and_members=c_users_and_groups)
-            print(Fore.YELLOW + "Run -> python3 graph_sso_complete.py " + Fore.RESET)
+            print(Fore.YELLOW + emoji.emojize(":sparkles:  Run -> python3 graph_sso_complete.py " + Fore.RESET))
     else:
-        print(Fore.RED + f"The cloud provider {args.cloud} is no available" + Fore.RESET)
+        print(Fore.RED + emoji.emojize(":warning: " + f"The cloud provider {args.cloud} is no available" + Fore.RESET))
     if args.version:
         get_version(version=__version__)
 
